summaryrefslogtreecommitdiffstats
path: root/camera/OMXCameraAdapter/OMXAlgo.cpp
diff options
context:
space:
mode:
authorEmilian Peev <epeev@mm-sol.com>2012-01-04 08:51:27 +0200
committerDaniel Levin <dendy@ti.com>2012-07-25 08:55:38 -0500
commitfff7b95bdf9f280754cc03cec6df19759899ed05 (patch)
treee1fe4523dad7a38a4110ffd2b65ac84906a32f07 /camera/OMXCameraAdapter/OMXAlgo.cpp
parent3b3270ebd0af3c3f22b4b6cfa9a7519df15f245c (diff)
downloadhardware_ti_omap4-fff7b95bdf9f280754cc03cec6df19759899ed05.zip
hardware_ti_omap4-fff7b95bdf9f280754cc03cec6df19759899ed05.tar.gz
hardware_ti_omap4-fff7b95bdf9f280754cc03cec6df19759899ed05.tar.bz2
CameraHal: Reconfigure preview port for resolutions 720p and higher
Change-Id: Ie6616c57661947cf61c671d9e90417696b44dd3d Signed-off-by: Emilian Peev <epeev@mm-sol.com>
Diffstat (limited to 'camera/OMXCameraAdapter/OMXAlgo.cpp')
-rw-r--r--camera/OMXCameraAdapter/OMXAlgo.cpp5
1 files changed, 3 insertions, 2 deletions
diff --git a/camera/OMXCameraAdapter/OMXAlgo.cpp b/camera/OMXCameraAdapter/OMXAlgo.cpp
index 3c18d99..48ae72f 100644
--- a/camera/OMXCameraAdapter/OMXAlgo.cpp
+++ b/camera/OMXCameraAdapter/OMXAlgo.cpp
@@ -1068,10 +1068,11 @@ status_t OMXCameraAdapter::setSensorOrientation(unsigned int degree)
}
/* Set Temproary Port resolution.
* For resolution with height > 1008,resolution cannot be set without configuring orientation.
* So we first set a temp resolution. We have used VGA
*/
- if ( mPreviewData->mHeight >= 1008 ) {
+ if ( mPreviewData->mHeight >= 720 ) {
tmpHeight = mPreviewData->mHeight;
tmpWidth = mPreviewData->mWidth;
mPreviewData->mWidth = 640;
@@ -1068,10 +1068,11 @@ status_t OMXCameraAdapter::setSensorOrientation(unsigned int degree)
}
/* Set Temproary Port resolution.
- * For resolution with height > 1008,resolution cannot be set without configuring orientation.
+ * For resolution with height >= 720,
+ * resolution cannot be set without configuring orientation.
* So we first set a temp resolution. We have used VGA
*/